@@ -19,7 +19,7 @@ import os
 from calculate.consolegui import qt
 
 from more import LabelWordWrap, FileOpenWgt, show_msg, show_question, \
-                 client_list_methods
+                 client_list_methods, get_icon, dpivalue
 
 class ToolsWidget (qt.QWidget):
     def __init__(self, parent, ClientObj, window):
@@ -31,10 +31,10 @@ class ToolsWidget (qt.QWidget):
 #        self.move(100+parent.frameGeometry().x(), \
 #                          100+parent.frameGeometry().y())
 
-        self.setFixedSize(450, 220)
+        self.setFixedSize(dpivalue(450), 100 + dpivalue(120))
         self.setWindowTitle(_('Preferences'))
 
-        self.setWindowIcon(qt.QIcon.fromTheme("preferences-other"))
+        self.setWindowIcon(get_icon("preferences-other"))
         # for clear memory after closed this window
         self.setWindowModality(qt.Qt.WindowModal)
         self.setAttribute(qt.Qt.WA_DeleteOnClose)
@@ -57,9 +57,8 @@ class ToolsWidget (qt.QWidget):
                 del (child)            
 
         # Add clear config button
-        clear_icon = qt.QIcon.fromTheme("edit-delete-page")
-        clear_button = qt.QPushButton (clear_icon,
-                                    _('Clear the configuration file'),self)
+        clear_button = qt.QPushButton(get_icon("edit-delete-page"),
+                                      _('Clear the configuration file'),self)
         clear_button.clicked.connect(self.clear_config(parent, ClientObj))
 
         self.vlayout.addWidget(clear_button)
@@ -75,19 +74,16 @@ class ToolsWidget (qt.QWidget):
         self.botton_layout.setAlignment(qt.Qt.AlignRight)
 
         toolOk = qt.QPushButton(_('Ok'), self)
-        toolOk.setFixedWidth(50)
         toolOk.setShortcut(qt.QKeySequence(qt.Qt.Key_Return))
         toolOk.clicked.connect(self.save_changes(ClientObj, tab))
         toolOk.clicked.connect(self.close)
         self.botton_layout.addWidget(toolOk)
 
         toolApply = qt.QPushButton(_('Apply'), self)
-        toolApply.setFixedWidth(100)
         toolApply.clicked.connect(self.save_changes(ClientObj, tab))
         self.botton_layout.addWidget(toolApply)
 
         toolQuit = qt.QPushButton(_('Cancel'), self)
-        toolQuit.setFixedWidth(100)
         toolQuit.clicked.connect(self.close)
         toolQuit.setShortcut(qt.QKeySequence(qt.Qt.Key_Escape))
         self.botton_layout.addWidget(toolQuit)
@@ -99,7 +95,7 @@ class ToolsWidget (qt.QWidget):
         self.vlayout.addWidget(botton_wgt)
 
 #        clear_button.setMaximumWidth(self.sizeHint().width() / 2)
-        clear_button.setMaximumWidth(220)
+        clear_button.setMaximumWidth(dpivalue(220))
 
     def save_changes(self, ClientObj, tab):
         def wrapper():
@@ -132,11 +128,9 @@ class ToolTabWidget(qt.QTabWidget):
 
         self.OtherWidget = ToolOther(self, ClientObj)
 
-        self.gui_icon = qt.QIcon.fromTheme("video-display")
+        self.gui_icon = get_icon("video-display")
 
-        self.other_icon = qt.QIcon.fromTheme("preferences-other")
-        if self.other_icon.isNull():
-            self.other_icon = qt.QIcon.fromTheme("preferences-desctop")
+        self.other_icon = get_icon("preferences-other", "preferences-desktop")
 
         self.addTab(self.GuiWidget, self.gui_icon ,_('GUI'))
         self.addTab(self.OtherWidget, self.other_icon, _('Other'))
